=======
History
=======

0.1.0 (2017-10-23)
------------------


* Add multiple pattern to picard insert metrics (#15)
* Add support for wide table output (#12)
* Add regex annotation to annotate_by_uri (#13)
* Add parser for samtools idxstats (#11)



Alpha releases
---------------

0.1.0-alpha.1 (2017-09-25)
--------------------------

* Replace aggregate functions with aggregate_factory


0.1.0-alpha.0 (2017-05-24)
--------------------------

* First alpha release.
